@@ -80,11 +80,13 @@ class NotebookResultBase(object):
     status = attr.ib(default=JobStatus.ERROR)
     overrides = attr.ib(default=attr.Factory(dict))
     mailto = attr.ib(default="")
+    error_mailto = attr.ib(default="")
     generate_pdf_output = attr.ib(default=True)
     hide_code = attr.ib(default=False)
     stdout = attr.ib(default=attr.Factory(list))
     scheduler_job_id = attr.ib(default=None)
     mailfrom = attr.ib(default=None)
+    email_subject = attr.ib(default=None)
     is_slideshow = attr.ib(default=False)
 
     def saveable_output(self):
@@ -100,6 +102,7 @@ class NotebookResultPending(NotebookResultBase):
     report_title = attr.ib(default="")
     overrides = attr.ib(default=attr.Factory(dict))
     mailto = attr.ib(default="")
+    error_mailto = attr.ib(default="")
     generate_pdf_output = attr.ib(default=True)
     hide_code = attr.ib(default=False)
     scheduler_job_id = attr.ib(default=None)
@@ -115,15 +118,13 @@ class NotebookResultError(NotebookResultBase):
     report_title = attr.ib(default="")
     overrides = attr.ib(default=attr.Factory(dict))
     mailto = attr.ib(default="")
+    error_mailto = attr.ib(default="")
     generate_pdf_output = attr.ib(default=True)
     hide_code = attr.ib(default=False)
     scheduler_job_id = attr.ib(default=None)
     mailfrom = attr.ib(default=None)
     is_slideshow = attr.ib(default=False)
-
-    @property
-    def email_subject(self):
-        return ""
+    email_subject = attr.ib(default=None)
 
     @property
     def raw_html(self):
@@ -155,6 +156,7 @@ class NotebookResultComplete(NotebookResultBase):
     report_title = attr.ib(default="")
     overrides = attr.ib(default=attr.Factory(dict))
     mailto = attr.ib(default="")
+    error_mailto = attr.ib(default="")
     email_subject = attr.ib(default="")
     generate_pdf_output = attr.ib(default=True)
     hide_code = attr.ib(default=False)
@@ -185,6 +187,7 @@ class NotebookResultComplete(NotebookResultBase):
             "job_start_time": self.job_start_time,
             "job_finish_time": self.job_finish_time,
             "mailto": self.mailto,
+            "error_mailto": self.error_mailto,
             "email_subject": self.email_subject,
             "overrides": self.overrides,
             "generate_pdf_output": self.generate_pdf_output,
@@ -200,9 +203,9 @@ class NotebookResultComplete(NotebookResultBase):
         return (
             "NotebookResultComplete(job_id={job_id}, status={status}, report_name={report_name}, "
             "job_start_time={job_start_time}, job_finish_time={job_finish_time}, update_time={update_time}, "
-            "report_title={report_title}, overrides={overrides}, mailto={mailto}, mailfrom={mailfrom}"
-            "email_subject={email_subject}, generate_pdf_output={generate_pdf_output}, hide_code={hide_code}, "
-            "scheduler_job_id={scheduler_job_id}, is_slideshow={is_slideshow})".format(
+            "report_title={report_title}, overrides={overrides}, mailto={mailto}, error_mailto={error_mailto}, "
+            "mailfrom={mailfrom}, email_subject={email_subject}, generate_pdf_output={generate_pdf_output}, "
+            "hide_code={hide_code}, scheduler_job_id={scheduler_job_id}, is_slideshow={is_slideshow})".format(
                 job_id=self.job_id,
                 status=self.status,
                 report_name=self.report_name,
@@ -212,6 +215,7 @@ class NotebookResultComplete(NotebookResultBase):
                 report_title=self.report_title,
                 overrides=self.overrides,
                 mailto=self.mailto,
+                error_mailto=self.error_mailto,
                 mailfrom=self.mailfrom,
                 email_subject=self.email_subject,
                 generate_pdf_output=self.generate_pdf_output,
